{% if success %}
<div class="bg-green-900/30 border border-green-800 text-green-300 text-sm rounded-lg p-3 fade-in">
    <span class="font-medium">Classified:</span> {{ category }}
    <span class="text-green-500">({{ "%.0f" | format(confidence * 100) }}%)</span>
    <p class="text-green-400/70 text-xs mt-1">{{ message }}</p>
</div>
{% else %}
<div class="bg-red-900/30 border border-red-800 text-red-300 text-sm rounded-lg p-3 fade-in">
    <span class="font-medium">Error:</span> {{ message }}
</div>
{% endif %}
